==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/Input/vorbis/translations/vorbis_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/vorbis/translations/vorbis_plugin_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 project</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
